@@ -3,7 +3,7 @@
 import os
 import unittest
 from pathlib import Path
-from unittest.mock import call, mock_open, patch, MagicMock
+from unittest.mock import MagicMock, call, mock_open, patch
 
 from aind_data_schema.utils.json_writer import SchemaWriter
 
